aboutsummaryrefslogtreecommitdiff
path: root/drivers/scsi/53c7xx.c
diff options
context:
space:
mode:
authorThomas Gleixner <tglx@linutronix.de>2006-07-01 19:29:42 -0700
committerLinus Torvalds <torvalds@g5.osdl.org>2006-07-02 13:58:53 -0700
commit1d6f359a2e06296418481239f8054a878f36e819 (patch)
treee3ce0c69e4f34374f51f4e226374467ca80e3993 /drivers/scsi/53c7xx.c
parent5d8c8a2e8edc63d8aef7656678f41c6c603f0443 (diff)
[PATCH] irq-flags: scsi: Use the new IRQF_ constants
Signed-off-by: Thomas Gleixner <tglx@linutronix.de> Cc: Ingo Molnar <mingo@elte.hu> Cc: "David S. Miller" <davem@davemloft.net> Cc: Benjamin Herrenschmidt <benh@kernel.crashing.org> Cc: James Bottomley <James.Bottomley@steeleye.com> Signed-off-by: Andrew Morton <akpm@osdl.org> Signed-off-by: Linus Torvalds <torvalds@osdl.org>
Diffstat (limited to 'drivers/scsi/53c7xx.c')
-rw-r--r--drivers/scsi/53c7xx.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/drivers/scsi/53c7xx.c b/drivers/scsi/53c7xx.c
index c9bd0335995..c690c2b89e4 100644
--- a/drivers/scsi/53c7xx.c
+++ b/drivers/scsi/53c7xx.c
@@ -1070,7 +1070,7 @@ NCR53c7x0_init (struct Scsi_Host *host) {
NCR53c7x0_driver_init (host);
- if (request_irq(host->irq, NCR53c7x0_intr, SA_SHIRQ, "53c7xx", host))
+ if (request_irq(host->irq, NCR53c7x0_intr, IRQF_SHARED, "53c7xx", host))
{
printk("scsi%d : IRQ%d not free, detaching\n",
host->host_no, host->irq);
@@ -4232,7 +4232,7 @@ restart:
* Purpose : handle NCR53c7x0 interrupts for all NCR devices sharing
* the same IRQ line.
*
* Inputs : Since we're using the SA_INTERRUPT interrupt handler
* semantics, irq indicates the interrupt which invoked
* this handler.
*
@@ -4232,7 +4232,7 @@ restart:
* the same IRQ line.
*
- * Inputs : Since we're using the SA_INTERRUPT interrupt handler
+ * Inputs : Since we're using the IRQF_DISABLED interrupt handler
* semantics, irq indicates the interrupt which invoked
* this handler.